@@ -1,13 +1,15 @@
 //! [Parigot list](https://ifl2014.github.io/submissions/ifl2014_submission_13.pdf)
 
-use crate::term::{Term, abs, app, UD};
+use crate::data::boolean::{fls, tru};
 use crate::term::Term::*;
-use crate::data::boolean::{tru, fls};
+use crate::term::{abs, app, Term, UD};
 
 /// Produces a `nil`, the last link of a Parigot-encoded list; equivalent to `boolean::tru`.
 ///
 /// NIL ≡ λab.a ≡ λ λ 2 ≡ TRUE
-pub fn nil() -> Term { tru() }
+pub fn nil() -> Term {
+    tru()
+}
 
 /// Applied to a Parigot-encoded list it determines if it is empty.
 ///
@@ -56,17 +58,15 @@ pub fn is_nil() -> Term {
 /// );
 /// ```
 pub fn cons() -> Term {
-    abs!(4, app!(
-        Var(1),
-        Var(4),
-        Var(3),
+    abs!(
+        4,
         app!(
-            abs(Var(1)),
+            Var(1),
+            Var(4),
             Var(3),
-            Var(2),
-            Var(1)
+            app!(abs(Var(1)), Var(3), Var(2), Var(1))
         )
-    ))
+    )
 }
 
 /// Applied to a Parigot-encoded list it returns its first element.
