@@ -1,11 +1,11 @@
 //! [Church numerals](https://en.wikipedia.org/wiki/Church_encoding#Church_numerals)
 
-use crate::term::{Term, abs, app};
-use crate::term::Term::*;
-use crate::data::boolean::{tru, fls, and, or, not};
-use crate::data::num::{scott, parigot, stumpfu};
-use crate::data::pair::pair;
 use crate::combinators::{I, K, Z};
+use crate::data::boolean::{and, fls, not, or, tru};
+use crate::data::num::{parigot, scott, stumpfu};
+use crate::data::pair::pair;
+use crate::term::Term::*;
+use crate::term::{abs, app, Term};
 
 /// Produces a Church-encoded number zero; equivalent to `boolean::fls`.
 ///
@@ -18,7 +18,9 @@ use crate::combinators::{I, K, Z};
 ///
 /// assert_eq!(zero(), 0.into_church());
 /// ```
-pub fn zero() -> Term { fls() }
+pub fn zero() -> Term {
+    fls()
+}
 
 /// Applied to a Church-encoded number it produces a lambda-encoded boolean, indicating whether its
 /// argument is equal to zero.
@@ -81,12 +83,15 @@ pub fn succ() -> Term {
 /// assert_eq!(beta(app(pred(), 3.into_church()), NOR, 0), 2.into_church());
 /// ```
 pub fn pred() -> Term {
-    abs!(3, app!(
-        Var(3),
-        abs!(2, app(Var(1), app(Var(2), Var(4)))),
-        abs(Var(2)),
-        abs(Var(1))
-    ))
+    abs!(
+        3,
+        app!(
+            Var(3),
+            abs!(2, app(Var(1), app(Var(2), Var(4)))),
+            abs(Var(2)),
+            abs(Var(1))
+        )
+    )
 }
 
 /// Applied to two Church-encoded numbers it produces their sum.
@@ -152,12 +157,7 @@ pub fn mul() -> Term {
 /// assert_eq!(beta(app!(pow(), 2.into_church(), 3.into_church()), NOR, 0), 8.into_church());
 /// ```
 pub fn pow() -> Term {
-    abs!(2, app!(
-        is_zero(),
-        Var(1),
-        one(),
-        app(Var(1), Var(2))
-    ))
+    abs!(2, app!(is_zero(), Var(1), one(), app(Var(1), Var(2))))
 }
 
 /// Applied to two Church-encoded numbers it returns a lambda-encoded boolean indicating whether
@@ -176,14 +176,7 @@ pub fn pow() -> Term {
 /// assert_eq!(beta(app!(lt(), 1.into_church(), 0.into_church()), NOR, 0), false.into());
 /// ```
 pub fn lt() -> Term {
-    abs!(2, app(
-        not(),
-        app!(
-            leq(),
-            Var(1),
-            Var(2)
-        )
-    ))
+    abs!(2, app(not(), app!(leq(), Var(1), Var(2))))
 }
 
 /// Applied to two Church-encoded numbers it returns a lambda-encoded boolean indicating whether
@@ -202,14 +195,7 @@ pub fn lt() -> Term {
 /// assert_eq!(beta(app!(leq(), 1.into_church(), 0.into_church()), NOR, 0), false.into());
 /// ```
 pub fn leq() -> Term {
-    abs!(2, app(
-        is_zero(),
-        app!(
-            sub(),
-            Var(2),
-            Var(1)
-        )
-    ))
+    abs!(2, app(is_zero(), app!(sub(), Var(2), Var(1))))
 }
 
 /// Applied to two Church-encoded numbers it returns a lambda-encoded boolean indicating whether
@@ -228,19 +214,14 @@ pub fn leq() -> Term {
 /// assert_eq!(beta(app!(eq(), 1.into_church(), 0.into_church()), NOR, 0), false.into());
 /// ```
 pub fn eq() -> Term {
-    abs!(2, app!(
-        and(),
+    abs!(
+        2,
         app!(
-            leq(),
-            Var(2),
-            Var(1)
-        ),
-        app!(
-            leq(),
-            Var(1),
-            Var(2)
+            and(),
+            app!(leq(), Var(2), Var(1)),
+            app!(leq(), Var(1), Var(2))
         )
-    ))
+    )
 }
 
 /// Applied to two Church-encoded numbers it returns a lambda-encoded boolean indicating whether
@@ -259,25 +240,14 @@ pub fn eq() -> Term {
 /// assert_eq!(beta(app!(neq(), 1.into_church(), 0.into_church()), NOR, 0), true.into());
 /// ```
 pub fn neq() -> Term {
-    abs!(2, app!(
-        or(),
-        app(
-            not(),
-            app!(
-                leq(),
-                Var(2),
-                Var(1)
-            )
-        ),
-        app(
-            not(),
-            app!(
-                leq(),
-                Var(1),
-                Var(2)
-            )
+    abs!(
+        2,
+        app!(
+            or(),
+            app(not(), app!(leq(), Var(2), Var(1))),
+            app(not(), app!(leq(), Var(1), Var(2)))
         )
-    ))
+    )
 }
 
 /// Applied to two Church-encoded numbers it returns a lambda-encoded boolean indicating whether
@@ -296,11 +266,7 @@ pub fn neq() -> Term {
 /// assert_eq!(beta(app!(geq(), 1.into_church(), 0.into_church()), NOR, 0), true.into());
 /// ```
 pub fn geq() -> Term {
-    abs!(2, app!(
-        leq(),
-        Var(1),
-        Var(2)
-    ))
+    abs!(2, app!(leq(), Var(1), Var(2)))
 }
 
 /// Applied to two Church-encoded numbers it returns a lambda-encoded boolean indicating whether
@@ -319,14 +285,7 @@ pub fn geq() -> Term {
 /// assert_eq!(beta(app!(gt(), 1.into_church(), 0.into_church()), NOR, 0), true.into());
 /// ```
 pub fn gt() -> Term {
-    abs!(2, app(
-        not(),
-        app!(
-            leq(),
-            Var(2),
-            Var(1)
-        )
-    ))
+    abs!(2, app(not(), app!(leq(), Var(2), Var(1))))
 }
 
 /// Applied to two Church-encoded numbers it returns a Church-encoded pair with the result of their
@@ -355,23 +314,22 @@ pub fn gt() -> Term {
 pub fn div() -> Term {
     app!(
         Z(),
-        abs!(4, app!(
-            lt(),
-            Var(2),
-            Var(1),
-            abs(app!(
-                pair(),
-                Var(4),
-                Var(3)
-            )),
-            abs(app!(
-                Var(5),
-                app(succ(), Var(4)),
-                app!(sub(), Var(3), Var(2)),
-                Var(2)
-            )),
-            I()
-        )),
+        abs!(
+            4,
+            app!(
+                lt(),
+                Var(2),
+                Var(1),
+                abs(app!(pair(), Var(4), Var(3))),
+                abs(app!(
+                    Var(5),
+                    app(succ(), Var(4)),
+                    app!(sub(), Var(3), Var(2)),
+                    Var(2)
+                )),
+                I()
+            )
+        ),
         zero()
     )
 }
@@ -395,21 +353,20 @@ pub fn div() -> Term {
 pub fn quot() -> Term {
     app(
         Z(),
-        abs!(3, app!(
-            lt(),
-            Var(2),
-            Var(1),
-            abs(zero()),
-            abs(app(
-                succ(),
-                app!(
-                    Var(4),
-                    app!(sub(), Var(3), Var(2)),
-                    Var(2)
-                )
-            )),
-            I()
-        ))
+        abs!(
+            3,
+            app!(
+                lt(),
+                Var(2),
+                Var(1),
+                abs(zero()),
+                abs(app(
+                    succ(),
+                    app!(Var(4), app!(sub(), Var(3), Var(2)), Var(2))
+                )),
+                I()
+            )
+        ),
     )
 }
 
@@ -431,19 +388,18 @@ pub fn quot() -> Term {
 pub fn rem() -> Term {
     app(
         Z(),
-        abs!(3, app!(
-            lt(),
-            Var(2),
-            Var(1),
-            abs(Var(3)),
-            abs(app!(
-                Var(4),
-                app!(sub(), Var(3), Var(2)),
-                Var(2)
-            )),
-            I()
-        ))
-     )
+        abs!(
+            3,
+            app!(
+                lt(),
+                Var(2),
+                Var(1),
+                abs(Var(3)),
+                abs(app!(Var(4), app!(sub(), Var(3), Var(2)), Var(2))),
+                I()
+            )
+        ),
+    )
 }
 
 /// Applied to a Church-encoded number it yields its Church-encoded factorial.
@@ -465,11 +421,10 @@ pub fn rem() -> Term {
 pub fn fac() -> Term {
     abs(app!(
         Var(1),
-        abs!(3, app!(
-            Var(3),
-            app!(mul(), Var(2), Var(1)),
-            app!(succ(), Var(1))
-        )),
+        abs!(
+            3,
+            app!(Var(3), app!(mul(), Var(2), Var(1)), app!(succ(), Var(1)))
+        ),
         K(),
         one(),
         one()
@@ -488,15 +443,7 @@ pub fn fac() -> Term {
 /// assert_eq!(beta(app!(min(), 4.into_church(), 3.into_church()), NOR, 0), 3.into_church());
 /// ```
 pub fn min() -> Term {
-	abs!(2, app!(
-        app!(
-            leq(),
-            Var(2),
-            Var(1)
-        ),
-        Var(2),
-        Var(1)
-    ))
+    abs!(2, app!(app!(leq(), Var(2), Var(1)), Var(2), Var(1)))
 }
 
 /// Applied to two Church-encoded numbers it returns the greater one.
@@ -511,15 +458,7 @@ pub fn min() -> Term {
 /// assert_eq!(beta(app!(max(), 4.into_church(), 3.into_church()), NOR, 0), 4.into_church());
 /// ```
 pub fn max() -> Term {
-	abs!(2, app!(
-        app!(
-            leq(),
-            Var(2),
-            Var(1)
-        ),
-        Var(1),
-        Var(2)
-    ))
+    abs!(2, app!(app!(leq(), Var(2), Var(1)), Var(1), Var(2)))
 }
 
 /// Applied to two Church-encoded numbers `a` and `b` it returns the left [logical
@@ -537,18 +476,10 @@ pub fn max() -> Term {
 /// assert_eq!(beta(app!(shl(), 2.into_church(), 0.into_church()), NOR, 0), 2.into_church());
 /// ```
 pub fn shl() -> Term {
-    abs!(2, app!(
-        mul(),
-        Var(2),
-        app!(
-            pow(),
-            app(
-                succ(),
-                one()
-            ),
-            Var(1)
-        )
-    ))
+    abs!(
+        2,
+        app!(mul(), Var(2), app!(pow(), app(succ(), one()), Var(1)))
+    )
 }
 
 /// Applied to two Church-encoded numbers `a` and `b` it returns the right [logical
@@ -567,20 +498,15 @@ pub fn shl() -> Term {
 /// assert_eq!(beta(app!(shr(), 2.into_church(), 0.into_church()), NOR, 0), 2.into_church());
 /// ```
 pub fn shr() -> Term {
-    abs!(2, app!(
-        is_zero(),
-        Var(1),
-        Var(2),
+    abs!(
+        2,
         app!(
-            quot(),
+            is_zero(),
+            Var(1),
             Var(2),
-            app!(
-                pow(),
-                app(succ(), one()),
-                Var(1)
-            )
+            app!(quot(), Var(2), app!(pow(), app(succ(), one()), Var(1)))
         )
-    ))
+    )
 }
 
 /// Applied to a Church-encoded number it produces a lambda-encoded boolean, indicating whether its
