@@ -1,10 +1,9 @@
 //! [β-reduction](https://en.wikipedia.org/wiki/Beta_normal_form) for lambda `Term`s
 
-use crate::term::{Term, TermError};
-use crate::term::Term::*;
-use std::fmt;
-use std::mem;
 pub use self::Order::*;
+use crate::term::Term::*;
+use crate::term::{Term, TermError};
+use std::{cmp, fmt, mem};
 
 /// The [evaluation order](http://www.cs.cornell.edu/courses/cs6110/2014sp/Handouts/Sestoft.pdf) of
 /// β-reductions.
@@ -31,7 +30,7 @@ pub enum Order {
     CBV,
     /// hybrid applicative - a mix between `CBV` (call-by-value) and `APP` (applicative) strategies;
     /// usually the fastest-reducing normalizing strategy
-    HAP
+    HAP,
 }
 
 /// Performs β-reduction on a `Term` with the specified evaluation `Order` and an optional limit on
@@ -76,22 +75,24 @@ impl Term {
         self._apply(rhs, 0);
 
         let ret = mem::replace(self, Var(0)); // replace self with a dummy
-        let _ = mem::replace(self, ret.unabs().unwrap()); // move unabstracted self back to its place
+        *self = ret.unabs().unwrap(); // move unabstracted self back to its place
 
         Ok(())
     }
 
     fn _apply(&mut self, rhs: &Term, depth: usize) {
         match self {
-            Var(i) => if *i == depth {
-                *self = rhs.to_owned(); // substitute a top-level variable from lhs with rhs
-                self.update_free_variables(depth - 1, 0); // update indices of free variables from rhs
-            } else if *i > depth {
-                *self = Var(*i - 1) // decrement a free variable's index
-            },
-            Abs(ref mut abstracted) => {
-                abstracted._apply(rhs, depth + 1)
+            Var(i) => match (*i).cmp(&depth) {
+                cmp::Ordering::Equal => {
+                    *self = rhs.to_owned(); // substitute a top-level variable from lhs with rhs
+                    self.update_free_variables(depth - 1, 0); // update indices of free variables from rhs
+                }
+                cmp::Ordering::Greater => {
+                    *self = Var(*i - 1); // decrement a free variable's index
+                }
+                _ => {}
             },
+            Abs(ref mut abstracted) => abstracted._apply(rhs, depth + 1),
             App(boxed) => {
                 let (ref mut lhs_lhs, ref mut lhs_rhs) = **boxed;
                 lhs_lhs._apply(rhs, depth);
@@ -102,12 +103,12 @@ impl Term {
 
     fn update_free_variables(&mut self, added_depth: usize, own_depth: usize) {
         match self {
-            Var(ref mut i) => if *i > own_depth {
-                *i += added_depth
-            },
-            Abs(ref mut abstracted) => {
-                abstracted.update_free_variables(added_depth, own_depth + 1)
-            },
+            Var(ref mut i) => {
+                if *i > own_depth {
+                    *i += added_depth
+                }
+            }
+            Abs(ref mut abstracted) => abstracted.update_free_variables(added_depth, own_depth + 1),
             App(boxed) => {
                 let (ref mut lhs, ref mut rhs) = **boxed;
                 lhs.update_free_variables(added_depth, own_depth);
@@ -120,13 +121,13 @@ impl Term {
         let to_apply = mem::replace(self, Var(0)); // replace self with a dummy
         let (mut lhs, rhs) = to_apply.unapp().unwrap(); // safe; only called in reduction sites
         lhs.apply(&rhs).unwrap(); // ditto
-        let _ = mem::replace(self, lhs); // move self back to its place
+        *self = lhs; // move self back to its place
 
         *count += 1;
     }
 
     fn is_reducible(&self, limit: usize, count: usize) -> bool {
-        self.lhs_ref().and_then(|t| t.unabs_ref()).is_ok() && (limit == 0 || count < limit )
+        self.lhs_ref().and_then(|t| t.unabs_ref()).is_ok() && (limit == 0 || count < limit)
     }
 
     /// Performs β-reduction on a `Term` with the specified evaluation `Order` and an optional limit
@@ -155,14 +156,16 @@ impl Term {
             APP => self.beta_app(limit, &mut count),
             HSP => self.beta_hsp(limit, &mut count),
             HNO => self.beta_hno(limit, &mut count),
-            HAP => self.beta_hap(limit, &mut count)
+            HAP => self.beta_hap(limit, &mut count),
         }
 
         count
     }
 
     fn beta_cbn(&mut self, limit: usize, count: &mut usize) {
-        if limit != 0 && *count == limit { return }
+        if limit != 0 && *count == limit {
+            return;
+        }
 
         if let App(_) = *self {
             self.lhs_mut().unwrap().beta_cbn(limit, count);
@@ -175,7 +178,9 @@ impl Term {
     }
 
     fn beta_nor(&mut self, limit: usize, count: &mut usize) {
-        if limit != 0 && *count == limit { return }
+        if limit != 0 && *count == limit {
+            return;
+        }
 
         match *self {
             Abs(ref mut abstracted) => abstracted.beta_nor(limit, count),
@@ -189,13 +194,15 @@ impl Term {
                     self.lhs_mut().unwrap().beta_nor(limit, count);
                     self.rhs_mut().unwrap().beta_nor(limit, count);
                 }
-            },
-            _ => ()
+            }
+            _ => (),
         }
     }
 
     fn beta_cbv(&mut self, limit: usize, count: &mut usize) {
-        if limit != 0 && *count == limit { return }
+        if limit != 0 && *count == limit {
+            return;
+        }
 
         if let App(_) = *self {
             self.lhs_mut().unwrap().beta_cbv(limit, count);
@@ -209,7 +216,9 @@ impl Term {
     }
 
     fn beta_app(&mut self, limit: usize, count: &mut usize) {
-        if limit != 0 && *count == limit { return }
+        if limit != 0 && *count == limit {
+            return;
+        }
 
         match *self {
             Abs(ref mut abstracted) => abstracted.beta_app(limit, count),
@@ -221,13 +230,15 @@ impl Term {
                     self.eval(count);
                     self.beta_app(limit, count);
                 }
-            },
-            _ => ()
+            }
+            _ => (),
         }
     }
 
     fn beta_hap(&mut self, limit: usize, count: &mut usize) {
-        if limit != 0 && *count == limit { return }
+        if limit != 0 && *count == limit {
+            return;
+        }
 
         match *self {
             Abs(ref mut abstracted) => abstracted.beta_hap(limit, count),
@@ -241,13 +252,15 @@ impl Term {
                 } else {
                     self.lhs_mut().unwrap().beta_hap(limit, count);
                 }
-            },
-            _ => ()
+            }
+            _ => (),
         }
     }
 
     fn beta_hsp(&mut self, limit: usize, count: &mut usize) {
-        if limit != 0 && *count == limit { return }
+        if limit != 0 && *count == limit {
+            return;
+        }
 
         match *self {
             Abs(ref mut abstracted) => abstracted.beta_hsp(limit, count),
@@ -258,13 +271,15 @@ impl Term {
                     self.eval(count);
                     self.beta_hsp(limit, count)
                 }
-            },
-            _ => ()
+            }
+            _ => (),
         }
     }
 
     fn beta_hno(&mut self, limit: usize, count: &mut usize) {
-        if limit != 0 && *count == limit { return }
+        if limit != 0 && *count == limit {
+            return;
+        }
 
         match *self {
             Abs(ref mut abstracted) => abstracted.beta_hno(limit, count),
@@ -278,22 +293,26 @@ impl Term {
                     self.lhs_mut().unwrap().beta_hno(limit, count);
                     self.rhs_mut().unwrap().beta_hno(limit, count);
                 }
-            },
-            _ => ()
+            }
+            _ => (),
         }
     }
 }
 
 impl fmt::Display for Order {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        write!(f, "{}", match *self {
-            NOR => "normal",
-            CBN => "call-by-name",
-            HSP => "head spine",
-            HNO => "hybrid normal",
-            APP => "applicative",
-            CBV => "call-by-value",
-            HAP => "hybrid applicative"
-        })
+        write!(
+            f,
+            "{}",
+            match *self {
+                NOR => "normal",
+                CBN => "call-by-name",
+                HSP => "head spine",
+                HNO => "hybrid normal",
+                APP => "applicative",
+                CBV => "call-by-value",
+                HAP => "hybrid applicative",
+            }
+        )
     }
 }
